/*****************************************************************************
* File:	     	fits_obj.h
* Programmer: 	Dorian Winterfeld
* 		Anne Raugh
* Institution:  PDS/Small Bodies Node
*               University of Maryland
* Abstract: 	Prototype of functions related to the FITS object.
*****************************************************************************/

#include "pds_tbl.h"

#ifndef OBJ_HDR
#define OBJ_HDR

/* data structure for FITS keyword */
typedef struct keyword
{
 char	 name[100];           /* name of keyword */
 char	 type[20];            /* general data type of keyword */
 char	 *value;  	      /* pointer to the output string */
 int      required;            /* true if required */
 struct   keyword *next;       /* pointer to next keyword in list */
 struct   keyword *prev;
} FITS_keyword;


/* data structure for FITS object */
typedef struct object
{
 char	       name[100];       /* name of object */
 int	       extension;       /* TRUE if object is extension */
 int	       ext_cnt;		/* number of extension objects */
 int	       keyword_cnt;     /* number of keywords */
 FITS_keyword   *keyword_list;  /* pointer to keyword list */
 struct object  *next;          /* pointer to list of objects at same level*/
 struct object	*prev;          /* of hierachy */
} FITS_object;

/* function declarations */

int setup_FITS_object(table *ttable,FITS_object **main_object );
FITS_object *create_FITS_object(char *type, FITS_object *main);
int add_required_keys(FITS_object *object);
FITS_keyword *create_FITS_keyword(char *keyword, FITS_object *parent);
void get_subobj(char *PDS_form,char *subobj);

#endif
